import React from 'react'; // props

import defaultProps from "./props/defaultProps";
import { propTypes } from "./props/propTypes"; // methods

import cssJSLogic from "./css/cssJSLogic";
import { mergeStyle } from '@zohodesk/utils'; // constants

import { offLabelRadius, thumbRadius } from "./contants"; // components

import Flex from '@zohodesk/layout/es/Flex/Flex';
import Label from "../../Label/Label"; // css

import defaultStyle from "./css/Switch_v2.module.css";

const Switch = props => {
  const {
    name,
    value,
    id,
    size,
    isChecked,
    isDisabled,
    isReadOnly,
    onChange,
    hasOnOffIndication,
    labelText,
    labelPalette,
    labelPlacement,
    labelSize,
    title,
    customProps_container,
    customProps_label,
    tagAttributes_container,
    tagAttributes_switch,
    a11yAttributes_container,
    a11yAttributes_switch,
    a11yAttributes_label,
    customId,
    testId,
    customStyle
  } = props;
  const {
    role = 'switch',
    extraA11yAttributes_switch
  } = a11yAttributes_switch;
  const style = mergeStyle(defaultStyle, customStyle);
  const {
    containerClass,
    labelClass,
    trackClass,
    trackWrapperClass,
    thumbClass,
    labelIndicationClass
  } = cssJSLogic({
    props,
    style
  });
  return /*#__PURE__*/React.createElement(Flex, {
    $ui_displayMode: "inline",
    $ui_direction: labelPlacement === 'left' ? 'row' : 'rowReverse',
    $ui_alignItems: "center",
    $tagAttributes_container: {
      'data-selector-id': customId,
      ...tagAttributes_container
    },
    testId: testId,
    customId: customId,
    customStyle: {
      inlineFlex: containerClass
    },
    $a11yAttributes_container: a11yAttributes_container,
    ...customProps_container
  }, labelText && /*#__PURE__*/React.createElement(Label, {
    text: labelText,
    palette: labelPalette,
    size: labelSize,
    htmlFor: id,
    customClass: labelClass,
    a11y: a11yAttributes_label,
    ...customProps_label
  }), /*#__PURE__*/React.createElement(Flex, {
    $flag_shrink: false,
    customStyle: {
      noShrink: trackWrapperClass
    }
  }, /*#__PURE__*/React.createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    value: value,
    checked: isChecked,
    disabled: isDisabled,
    readOnly: isReadOnly,
    onChange: !isDisabled || !isReadOnly ? onChange : null,
    role: role,
    className: trackClass,
    "data-title": title,
    ...tagAttributes_switch,
    ...extraA11yAttributes_switch
  }), /*#__PURE__*/React.createElement("svg", {
    className: thumbClass,
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("circle", {
    cx: "50%",
    cy: "50%",
    r: thumbRadius[size]
  })), hasOnOffIndication ? /*#__PURE__*/React.createElement("svg", {
    className: labelIndicationClass,
    xmlns: "http://www.w3.org/2000/svg"
  }, isChecked ? /*#__PURE__*/React.createElement("rect", {
    width: "100%",
    height: "100%",
    rx: "50%"
  }) : /*#__PURE__*/React.createElement("circle", {
    cx: "50%",
    cy: "50%",
    r: offLabelRadius[size]
  })) : null));
};

export default Switch;
Switch.defaultProps = defaultProps;
Switch.propTypes = propTypes;